@@ -4,9 +4,8 @@ from astropy.cosmology import WMAP9 as cosmo
 import numpy as np
 import pandas as pd
 
-from astrorapid import helpers
+from astrorapid import helpers, model_early_lightcurve
 from astrorapid.ANTARES_object.LAobject import LAobject
-from astrorapid.ANTARES_object.features import model_early_lightcurve
 
 
 class InputLightCurve(object):
@@ -57,7 +56,7 @@ class InputLightCurve(object):
         self.objid = objid
         self.redshift = redshift
         self.mwebv = mwebv
-        self.known_redshift =known_redshift
+        self.known_redshift = known_redshift
         self.training_set_parameters = training_set_parameters
         if training_set_parameters is not None:
             self.class_number = training_set_parameters['class_number']
@@ -99,7 +98,8 @@ class InputLightCurve(object):
             calc_params = False
         elif len(self.t[inrange_mask]) < 3:  # No t0 if not At least 3 points before peak
             calc_params = False
-        elif len(self.t[self.t < 0]) < 3:  # No t0 if there are less than three points before trigger. This suggests that it triggered on one of the first point of a passband
+        elif len(self.t[
+                     self.t < 0]) < 3:  # No t0 if there are less than three points before trigger. This suggests that it triggered on one of the first point of a passband
             calc_params = False
 
         if calc_params:
@@ -134,7 +134,9 @@ class InputLightCurve(object):
             t0 = self.compute_t0(outlc)
             otherinfo += [t0, self.peakmjd]
 
-        savepd = {pb: pd.DataFrame(lcinfo).loc[[0, 5, 6, 7]].rename({0: 'time', 5: 'fluxRenorm', 6: 'fluxErrRenorm', 7: 'photflag'}).T for pb, lcinfo in outlc.items()}  # Convert to dataframe rows: time, fluxNorm, fluxNormErr, photFlag; columns: ugrizY
+        savepd = {pb: pd.DataFrame(lcinfo).loc[[0, 5, 6, 7]].rename(
+            {0: 'time', 5: 'flux', 6: 'fluxErr', 7: 'photflag', 8: 'zeropoint'}).T for pb, lcinfo in
+                  outlc.items()}  # Convert to dataframe rows: time, fluxNorm, fluxNormErr, photFlag; columns: ugrizY
         savepd['otherinfo'] = pd.DataFrame(otherinfo)
         savepd = pd.DataFrame(
             {(outerKey, innerKey): values for outerKey, innerDict in savepd.items() for innerKey, values in
@@ -158,9 +160,3 @@ def read_multiple_light_curves(light_curve_list, known_redshift=True, training_s
         processed_light_curves[objid] = inputlightcurve.preprocess_light_curve()
 
     return processed_light_curves
-
-
-
-
-
-
